/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.api.filters;

import com.google.common.base.Objects;
import com.google.common.base.Preconditions;
import org.eclipse.emf.diffmerge.patch.api.ChangeDirection;
import org.eclipse.emf.diffmerge.patch.api.IModelPatchEntryFilter;
import org.eclipse.emf.diffmerge.patch.api.ModelPatchEntry;
import org.eclipse.xtend.lib.annotations.AccessorType;
import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtext.xbase.lib.Pure;

@SuppressWarnings("all")
public class EntryDirectionFilter implements IModelPatchEntryFilter {
  @Accessors(AccessorType.PUBLIC_GETTER)
  private ChangeDirection filteredDirection;
  
  public EntryDirectionFilter(final ChangeDirection filteredDirection) {
    Preconditions.<ChangeDirection>checkNotNull(filteredDirection);
    this.filteredDirection = filteredDirection;
  }
  
  @Override
  public boolean isEntryFiltered(final ModelPatchEntry entry) {
    ChangeDirection _direction = entry.getDirection();
    return Objects.equal(_direction, this.filteredDirection);
  }
  
  @Pure
  public ChangeDirection getFilteredDirection() {
    return this.filteredDirection;
  }
}
