/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.api.filters;

import com.google.common.base.Objects;
import com.google.common.base.Preconditions;
import java.util.List;
import org.eclipse.emf.diffmerge.patch.api.EntryType;
import org.eclipse.emf.diffmerge.patch.api.IModelPatchEntryFilter;
import org.eclipse.emf.diffmerge.patch.api.ModelPatchEntry;
import org.eclipse.xtend.lib.annotations.AccessorType;
import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtext.xbase.lib.Conversions;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.IterableExtensions;
import org.eclipse.xtext.xbase.lib.Pure;

@SuppressWarnings("all")
public class EntryTypeFilter implements IModelPatchEntryFilter {
  @Accessors(AccessorType.PUBLIC_GETTER)
  private List<EntryType> filteredTypes;
  
  public EntryTypeFilter(final EntryType... filteredTypes) {
    Preconditions.<EntryType[]>checkNotNull(filteredTypes);
    this.filteredTypes = ((List<EntryType>)Conversions.doWrapArray(filteredTypes));
  }
  
  @Override
  public boolean isEntryFiltered(final ModelPatchEntry entry) {
    final Function1<EntryType, Boolean> _function = (EntryType it) -> {
      EntryType _entryType = entry.getEntryType();
      return Boolean.valueOf(Objects.equal(it, _entryType));
    };
    return IterableExtensions.<EntryType>exists(this.filteredTypes, _function);
  }
  
  @Pure
  public List<EntryType> getFilteredTypes() {
    return this.filteredTypes;
  }
}
