/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Balazs Grill, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.runtime.identifier;

import com.google.common.base.Objects;
import com.google.common.base.Optional;
import com.google.common.collect.Iterables;
import org.eclipse.emf.diffmerge.patch.runtime.identifier.EObjectLocator;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.IterableExtensions;
import org.eclipse.xtext.xbase.lib.IteratorExtensions;
import org.eclipse.xtext.xbase.lib.ListExtensions;

@SuppressWarnings("all")
public class TreeIteratorEObjectLocator implements EObjectLocator {
  private ResourceSet resourceSet;
  
  public TreeIteratorEObjectLocator(final ResourceSet resourceSet) {
    this.resourceSet = resourceSet;
  }
  
  @Override
  public Optional<EObject> locate(final String identifier) {
    final Function1<Resource, Iterable<EObject>> _function = (Resource it) -> {
      return IteratorExtensions.<EObject>toIterable(it.getAllContents());
    };
    final Iterable<EObject> allResourceContents = Iterables.<EObject>concat(ListExtensions.<Resource, Iterable<EObject>>map(this.resourceSet.getResources(), _function));
    final Function1<EObject, Boolean> _function_1 = (EObject element) -> {
      String _iD = EcoreUtil.getID(element);
      return Boolean.valueOf(Objects.equal(identifier, _iD));
    };
    final EObject eObject = IterableExtensions.<EObject>findFirst(allResourceContents, _function_1);
    return Optional.<EObject>fromNullable(eObject);
  }
}
