/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Balazs Grill, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.ui.utils;

import com.google.common.base.Objects;
import java.util.Arrays;
import org.eclipse.emf.diffmerge.patch.AttributeEntry;
import org.eclipse.emf.diffmerge.patch.ElementEntry;
import org.eclipse.emf.diffmerge.patch.ReferenceEntry;
import org.eclipse.emf.diffmerge.patch.StructuralFeatureEntry;
import org.eclipse.emf.diffmerge.patch.api.ChangeDirection;
import org.eclipse.emf.diffmerge.patch.api.EntryType;
import org.eclipse.emf.diffmerge.patch.api.Identifiable;
import org.eclipse.emf.diffmerge.patch.api.ModelPatchEntry;
import org.eclipse.emf.diffmerge.patch.ui.utils.DefaultEntryLabelProvider;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.StringExtensions;

@SuppressWarnings("all")
public class DescriptiveEntryLabelProvider extends DefaultEntryLabelProvider {
  @Override
  public String getLabel(final ModelPatchEntry entry) {
    return this.shortPrettyPrint(entry);
  }
  
  private String _shortPrettyPrint(final ModelPatchEntry entry) {
    StringConcatenation _builder = new StringConcatenation();
    ChangeDirection _direction = entry.getDirection();
    _builder.append(_direction);
    _builder.append(" ");
    EntryType _entryType = entry.getEntryType();
    _builder.append(_entryType);
    _builder.append(" ");
    {
      ChangeDirection _direction_1 = entry.getDirection();
      boolean _equals = Objects.equal(_direction_1, ChangeDirection.ADD);
      if (_equals) {
        _builder.append("TO");
      } else {
        _builder.append("FROM");
      }
    }
    _builder.append(" ");
    String _identifier = entry.getContext().getIdentifier();
    _builder.append(_identifier);
    return _builder.toString();
  }
  
  private String _shortPrettyPrint(final ElementEntry entry) {
    StringConcatenation _builder = new StringConcatenation();
    String _firstUpper = StringExtensions.toFirstUpper(this.decodeDirectionLabel(entry.getDirection(), true));
    _builder.append(_firstUpper);
    _builder.append(" \'");
    String _identifier = entry.getContext().getIdentifier();
    _builder.append(_identifier);
    _builder.append("\' (type: \'");
    String _typeString = this.getTypeString(entry.getType());
    _builder.append(_typeString);
    _builder.append("\')");
    return _builder.toString();
  }
  
  private String _shortPrettyPrint(final AttributeEntry entry) {
    if ((Objects.equal(entry.getIndex(), null) || (!entry.getIndex().isPresent()))) {
      StringConcatenation _builder = new StringConcatenation();
      String _firstUpper = StringExtensions.toFirstUpper(this.decodeDirectionLabel(entry.getDirection(), false));
      _builder.append(_firstUpper);
      _builder.append(" \'");
      String _featureString = this.getFeatureString(entry.getFeature());
      _builder.append(_featureString);
      _builder.append("\' attribute of \'");
      String _identifier = entry.getContext().getIdentifier();
      _builder.append(_identifier);
      _builder.append("\' ");
      {
        ChangeDirection _direction = entry.getDirection();
        boolean _equals = Objects.equal(_direction, ChangeDirection.ADD);
        if (_equals) {
          _builder.append("to \'");
          String _value = entry.getValue();
          _builder.append(_value);
          _builder.append("\'");
        } else {
          _builder.append("(old value: ");
          String _value_1 = entry.getValue();
          _builder.append(_value_1);
          _builder.append(")");
        }
      }
      return _builder.toString();
    } else {
      StringConcatenation _builder_1 = new StringConcatenation();
      String _firstUpper_1 = StringExtensions.toFirstUpper(this.decodeDirectionLabel(entry.getDirection(), true));
      _builder_1.append(_firstUpper_1);
      _builder_1.append(" \'");
      String _value_2 = entry.getValue();
      _builder_1.append(_value_2);
      _builder_1.append("\' value ");
      String _from = this.toFrom(entry.getDirection());
      _builder_1.append(_from);
      _builder_1.append(" the \'");
      String _featureString_1 = this.getFeatureString(entry.getFeature());
      _builder_1.append(_featureString_1);
      _builder_1.append("\' ");
      String _listEnding = this.getListEnding(entry);
      _builder_1.append(_listEnding);
      return _builder_1.toString();
    }
  }
  
  private String _shortPrettyPrint(final ReferenceEntry entry) {
    if ((Objects.equal(entry.getIndex(), null) || (!entry.getIndex().isPresent()))) {
      StringConcatenation _builder = new StringConcatenation();
      String _firstUpper = StringExtensions.toFirstUpper(this.decodeDirectionLabel(entry.getDirection(), false));
      _builder.append(_firstUpper);
      _builder.append(" \'");
      String _featureString = this.getFeatureString(entry.getFeature());
      _builder.append(_featureString);
      _builder.append("\' reference of \'");
      String _identifier = entry.getContext().getIdentifier();
      _builder.append(_identifier);
      _builder.append("\'");
      {
        ChangeDirection _direction = entry.getDirection();
        boolean _equals = Objects.equal(_direction, ChangeDirection.ADD);
        if (_equals) {
          _builder.append(" to \'");
          String _identifier_1 = entry.getTarget().getIdentifier();
          _builder.append(_identifier_1);
          _builder.append("\'");
        } else {
          _builder.append(" (old target: \'");
          String _identifier_2 = entry.getTarget().getIdentifier();
          _builder.append(_identifier_2);
          _builder.append("\')");
        }
      }
      return _builder.toString();
    } else {
      StringConcatenation _builder_1 = new StringConcatenation();
      String _firstUpper_1 = StringExtensions.toFirstUpper(this.decodeDirectionLabel(entry.getDirection(), true));
      _builder_1.append(_firstUpper_1);
      _builder_1.append(" reference to \'");
      String _identifier_3 = entry.getTarget().getIdentifier();
      _builder_1.append(_identifier_3);
      _builder_1.append("\' ");
      String _from = this.toFrom(entry.getDirection());
      _builder_1.append(_from);
      _builder_1.append(" the \'");
      String _featureString_1 = this.getFeatureString(entry.getFeature());
      _builder_1.append(_featureString_1);
      _builder_1.append("\' ");
      String _listEnding = this.getListEnding(entry);
      _builder_1.append(_listEnding);
      return _builder_1.toString();
    }
  }
  
  public String getListEnding(final StructuralFeatureEntry entry) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("list of \'");
    String _identifier = entry.getContext().getIdentifier();
    _builder.append(_identifier);
    _builder.append("\' (index: ");
    Integer _get = entry.getIndex().get();
    _builder.append(_get);
    _builder.append(")");
    return _builder.toString();
  }
  
  private String decodeDirectionLabel(final ChangeDirection direction, final boolean isAddRemove) {
    if (isAddRemove) {
      boolean _equals = Objects.equal(direction, ChangeDirection.ADD);
      if (_equals) {
        return "add";
      } else {
        return "remove";
      }
    } else {
      boolean _equals_1 = Objects.equal(direction, ChangeDirection.ADD);
      if (_equals_1) {
        return "set";
      } else {
        return "unset";
      }
    }
  }
  
  private String toFrom(final ChangeDirection direction) {
    boolean _equals = Objects.equal(direction, ChangeDirection.ADD);
    if (_equals) {
      return "to";
    } else {
      return "from";
    }
  }
  
  private String getTypeString(final Identifiable identifiable) {
    return identifiable.getIdentifier();
  }
  
  private String getFeatureString(final Identifiable identifiable) {
    return identifiable.getIdentifier();
  }
  
  private String shortPrettyPrint(final ModelPatchEntry entry) {
    if (entry instanceof AttributeEntry) {
      return _shortPrettyPrint((AttributeEntry)entry);
    } else if (entry instanceof ReferenceEntry) {
      return _shortPrettyPrint((ReferenceEntry)entry);
    } else if (entry instanceof ElementEntry) {
      return _shortPrettyPrint((ElementEntry)entry);
    } else if (entry != null) {
      return _shortPrettyPrint(entry);
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(entry).toString());
    }
  }
}
