/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Balazs Grill, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.ui.utils;

import java.util.Arrays;
import java.util.List;
import org.eclipse.emf.diffmerge.patch.api.EntryType;
import org.eclipse.emf.diffmerge.patch.api.filters.ComplexEntryFilter;
import org.eclipse.emf.diffmerge.patch.api.filters.EntryDirectionFilter;
import org.eclipse.emf.diffmerge.patch.api.filters.EntryTypeFilter;
import org.eclipse.jface.viewers.ILabelProvider;
import org.eclipse.jface.viewers.ILabelProviderListener;
import org.eclipse.swt.graphics.Image;
import org.eclipse.xtend2.lib.StringConcatenation;

@SuppressWarnings("all")
public class ModelPatchEntryFilterLabelProvider implements ILabelProvider {
  @Override
  public Image getImage(final Object element) {
    return null;
  }
  
  @Override
  public String getText(final Object element) {
    return this.getLabel(element);
  }
  
  private String _getLabel(final Object object) {
    return object.toString();
  }
  
  private String _getLabel(final ComplexEntryFilter filter) {
    StringConcatenation _builder = new StringConcatenation();
    String _name = filter.getType().name();
    _builder.append(_name);
    return _builder.toString();
  }
  
  private String _getLabel(final EntryDirectionFilter filter) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("Filtered direction: ");
    String _name = filter.getFilteredDirection().name();
    _builder.append(_name);
    return _builder.toString();
  }
  
  private String _getLabel(final EntryTypeFilter filter) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("Filtered entry types: ");
    {
      List<EntryType> _filteredTypes = filter.getFilteredTypes();
      boolean _hasElements = false;
      for(final EntryType type : _filteredTypes) {
        if (!_hasElements) {
          _hasElements = true;
        } else {
          _builder.appendImmediate(", ", "");
        }
        String _name = type.name();
        _builder.append(_name);
      }
    }
    return _builder.toString();
  }
  
  @Override
  public void addListener(final ILabelProviderListener listener) {
  }
  
  @Override
  public void dispose() {
  }
  
  @Override
  public boolean isLabelProperty(final Object element, final String property) {
    return true;
  }
  
  @Override
  public void removeListener(final ILabelProviderListener listener) {
  }
  
  private String getLabel(final Object filter) {
    if (filter instanceof ComplexEntryFilter) {
      return _getLabel((ComplexEntryFilter)filter);
    } else if (filter instanceof EntryDirectionFilter) {
      return _getLabel((EntryDirectionFilter)filter);
    } else if (filter instanceof EntryTypeFilter) {
      return _getLabel((EntryTypeFilter)filter);
    } else if (filter != null) {
      return _getLabel(filter);
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(filter).toString());
    }
  }
}
